"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const http_errors_1 = require("@curveball/http-errors");
const principalService = require("../../principal/service");
const service_1 = require("../service");
const oauth2Service = require("../../oauth2/service");
class EditClientController extends controller_1.default {
    async get(ctx) {
        const app = await principalService.findByExternalId(ctx.params.id, 'app');
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can add new OAuth2 clients');
        }
        const client = await (0, service_1.findByClientId)(ctx.params.clientId);
        if (client.app.id !== app.id) {
            throw new http_errors_1.NotFound('OAuth2 client not found');
        }
        ctx.response.body = hal.editForm(client, await oauth2Service.getRedirectUris(client));
    }
    async post(ctx) {
        const app = await principalService.findByExternalId(ctx.params.id, 'app');
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can inspect OAuth2 clients that are not your own');
        }
        const client = await (0, service_1.findByClientId)(ctx.params.clientId);
        if (client.app.id !== app.id) {
            throw new http_errors_1.NotFound('OAuth2 client not found');
        }
        const allowedGrantTypes = [];
        if (ctx.request.body.allowClientCredentials) {
            allowedGrantTypes.push('client_credentials');
        }
        if (ctx.request.body.allowAuthorizationCode) {
            allowedGrantTypes.push('authorization_code');
        }
        if (ctx.request.body.allowImplicit) {
            allowedGrantTypes.push('implicit');
        }
        if (ctx.request.body.allowRefreshToken) {
            allowedGrantTypes.push('refresh_token');
        }
        if (ctx.request.body.allowPassword) {
            allowedGrantTypes.push('password');
        }
        const redirectUris = ctx.request.body.redirectUris.trim().split(/\r\n|\n/).filter((line) => !!line);
        if (!allowedGrantTypes) {
            throw new http_errors_1.UnprocessableEntity('You must specify the allowedGrantTypes property');
        }
        client.allowedGrantTypes = allowedGrantTypes;
        client.requirePkce = ctx.request.body.requirePkce ?? false,
            await (0, service_1.edit)(client, redirectUris);
        ctx.redirect(303, client.href);
    }
}
exports.default = new EditClientController();
//# sourceMappingURL=edit.js.map